#!/usr/bin/env python

##########
# Imports
####

import optparse
from insights_coordinator_rhev.insights_coordinator_infra.parser.options_parser import CoordinatorParser
from insights_coordinator_rhev.insights_coordinator_infra.parser.options import CoordinatorCustomOption as RhevCoordinatorCustomOption


class RhevCoordinatorParser(CoordinatorParser):

    # Constructor
    def __init__(self, **kwargs):
        super(RhevCoordinatorParser, self).__init__(**kwargs)
        self.setup_options()
        self.setup_parser()

    # Setup the Options
    def setup_options(self):
        self.options = [

            # Get the current version of the coordinator
            optparse.make_option('--version', dest='version',
                                 help=self.language.get_language("This outputs the current version of the coordinator."),
                                 action='store_true',
                                 default=False),

            # Make this thing interactive
            # This is for debugging, goes through the logger and asks you if you want to continue to the next step
            optparse.make_option('-i', '--interactive', dest='interactive',
                                 help=self.language.get_language("This prompts for the exeuction of each step. "
                                                                 "This implies --verbose."),
                                 action='store_true',
                                 default=self.constants.interactive),

            # Make things Verbose
            optparse.make_option('-v', '--verbose', dest='verbose',
                                 help=self.language.get_language('In addition to logging to the Coordinator Logs, print output to the console.'),
                                 action='store_true',
                                 default=self.config.get_config_var('verbose')),

            # Archive Only
            optparse.make_option('--archive-only', dest='archive_only',
                                 help=self.language.get_language('Only create the Coordinator Archive in /tmp. '
                                                                 'This will not upload the final Archive to Red Hat.'),
                                 action='store_true',
                                 default=self.config.get_config_var('archive_only')),

            # Test API
            optparse.make_option('--test-api', dest='test_api',
                                 help=self.language.get_language('Only test the RHEV Manager API Connection. Coordinator will exit after test.'),
                                 action='store_true',
                                 default=self.constants.test_api),

            # API User
            optparse.make_option('--api-user', dest='api_user',
                                 help=self.language.get_language("Will allow using a specific RHEV API "
                                                                 "User during this execution of the coordinator. "
                                                                 "Will temporarily override any existing API "
                                                                 "User configured."),
                                 default=self.config.get_config_var('api_username')),

            # API Password
            optparse.make_option('--api-password', dest='api_password',
                                 help=self.language.get_language("Will prompt for a RHEV API password during this execution of the coordinator. Will temporarily override any existing API Password configured."),
                                 default=self.config.get_config_var('api_password')),

            # API URL
            RhevCoordinatorCustomOption('--api-url', dest='api_url',
                                        help=self.language.get_language('Will allow using a specific RHEV API URL during this execution of the coordinator. Will temporarily override any existing API URL configured.'),
                                        type='url', default=self.config.get_config_var('api_url')),

            # API Options
            optparse.make_option('--api-options', dest='api_options',
                                 help=self.language.get_language('Will allow using specific RHEV API Options for '
                                                                 'retrieval from the API. Will temporarily override '
                                                                 'any existing API Options configured.'),
                                 default=self.config.get_config_var('api_options')),

            # Test Hypervisors
            optparse.make_option('--test-hypervisors', dest='test_hypervisors',
                                 help=self.language.get_language('Will only test the Hypervisors connected to the '
                                                                 'RHEV Manager. The coordinator will exit after '
                                                                 'testing all Hypervisors.'),
                                 action='store_true',
                                 default=self.constants.test_hypervisors),

            # Disable Cron
            optparse.make_option('--disable-cron', dest='disable_cron',
                                 help=self.language.get_language('Will unlink and disable the Coordinator Cron Job.'),
                                 action='store_true',
                                 default=self.constants.disable_cron),

            # Enable Cron
            optparse.make_option('--enable-cron', dest='enable_cron',
                                 help=self.language.get_language('Will link and enable the Coordinator Cron Job.'),
                                 action='store_true',
                                 default=self.constants.enable_cron),

            # SSH User
            optparse.make_option('--ssh-user', dest='ssh_user', help=self.language.get_language('Will allow a specific runtime SSH User for this execution of the Coordinator to use for each Hypervisor. This will temporarily override any existing configured SSH user in the Coordinator configuration files.'),
                                 default=self.config.get_config_var('ssh_user')),

            # SSH Port
            RhevCoordinatorCustomOption('--ssh-port', dest='ssh_port', help=self.language.get_language('Will allow a specific runtime SSH Port for this execution of the Coordinator to use for each Hypervisor. This will temporarily override any existing configured SSH port in the Coordinator configuration files.'),
                                        type='port', default=self.config.get_config_var('ssh_port')),

            # SSH Key
            RhevCoordinatorCustomOption('--ssh-key', dest='ssh_key',
                                        help=self.language.get_language('Will allow a specific absolute path to a SSH Key for this runtime of the Coordinator for each Hypervisor. This will temporarily override any currently configured SSH key in the Coordinator configuraiton files.'),
                                        type='file', default=self.config.get_config_var('ssh_key')),

            # Configure
            optparse.make_option('--configure', dest='configure',
                                 help=self.language.get_language('Will run the Coordinator configuration utility. This will re-write the Coordinator configuration file to /etc/redhat-access-insights/insights-coordinator-rhev.conf. After running the utility the Coordinator will exit.'),
                                 action='store_true', default=self.constants.configure),

            # Manually run the soscleaner on the generated archive for this execution
            optparse.make_option('--run-soscleaner', dest='soscleaner',
                                 help=self.language.get_language('Manually trigger the SOSCleaner to be ran over the generated archive for this execution of the Coordinator.'),
                                 action='store_true', default=self.config.get_config_var('soscleaner')),

            # Blacklist any hypervisors/hostnames
            optparse.make_option('--blacklist', dest='blacklist',
                                 help=self.language.get_language('Will blacklist certain Hypervisors from the Insights data collection. This is a comma separated list of hostnames. Any hostname matching in this string will not be collected. This will temporarily override any currently configured blacklist defined in the Coordinator configuration files. Wildcards are accepted.'),
                                 default=self.config.get_config_var('blacklist'))
        ]
